///////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////

#include <owl\applicat.h>
#include <owl\mdi.h>
#include <owl\editsear.h>
#pragma hdrstop
#include "dymdimnu.rc"

#define BITMAP_W 129
#define BITMAP_H 97


class TChildWndw1: public TMDIChild
{
public:
	TChildWndw1(TMDIClient& parent, const char far* title);
};


TChildWndw1::TChildWndw1(TMDIClient& parent, const char far* title)
	: TMDIChild(parent, title, new TEditSearch)
{
	TMenuDescr menuDescr(MENU_2, 0, 2, 0, 0, 1, 0);
	SetMenuDescr(menuDescr);
}

///////////////////////////////////////////////////////////////////////////
class TBitmapWin: public TMDIChild {
public:
	TBitmapWin(TMDIClient& parent, const char far* title);
	~TBitmapWin();
	void GetWindowClass(WNDCLASS& wndClass);
	char far* GetClassName() {return "TBitmapWin";}
protected:
	void Paint(TDC& dc, BOOL erase, TRect& rect);
private:
	void CmShowBitmap();
	void CmHideBitmap();
	void CmEnableShowBitmap(TCommandEnabler &ce);
	void CmEnableHideBitmap(TCommandEnabler &ce);
	TBitmap *bitmap;
	BOOL showBitmap;
DECLARE_RESPONSE_TABLE(TBitmapWin);
};

DEFINE_RESPONSE_TABLE1(TBitmapWin, TMDIChild)
	EV_COMMAND(CM_SHOWBITMAP, CmShowBitmap),
	EV_COMMAND(CM_HIDEBITMAP, CmHideBitmap),
	EV_COMMAND_ENABLE(CM_SHOWBITMAP, CmEnableShowBitmap),
	EV_COMMAND_ENABLE(CM_HIDEBITMAP, CmEnableHideBitmap),
END_RESPONSE_TABLE;


TBitmapWin::TBitmapWin(TMDIClient& parent, const char far* title)
	: TMDIChild(parent, title),
		showBitmap(TRUE)
{
	bitmap = new TBitmap(
		GetApplicationObject()->GetInstance(),
		BITMAP_1);

	Attr.X = 100;
	Attr.Y = 70;
	Attr.W = BITMAP_W + 40;
	Attr.H = BITMAP_H + 60;

	Attr.Style &= ~(WS_MAXIMIZEBOX | WS_THICKFRAME |
		WS_MINIMIZEBOX | WS_SYSMENU);

	TMenuDescr menuDescr(MENU_3, 0, 0, 2, 0, 1, 0);
	SetMenuDescr(menuDescr);
}


TBitmapWin::~TBitmapWin()
{
	delete bitmap;
}


void TBitmapWin::GetWindowClass(WNDCLASS& wndClass)
{
	TMDIChild::GetWindowClass(wndClass);
	wndClass.hbrBackground = (HBRUSH)GetStockObject(BLACK_BRUSH);
}


void TBitmapWin::Paint(TDC& dc, BOOL /*erase*/, TRect& /*rect*/)
{
	if (showBitmap) {
		TMemoryDC memdc(dc);
		memdc.SelectObject(*bitmap);

		dc.BitBlt(
			20, 20,          		// Destination X,Y coordinate
			BITMAP_W, BITMAP_H, // Bitmap width and height
			memdc,              // Source device context
			0, 0,               // Source X,Y coordinate
			SRCCOPY);           // Raster display operation

		memdc.RestoreBitmap();   // Not strictly necessary
	}
}


void TBitmapWin::CmShowBitmap()
{
	showBitmap = TRUE;
	Invalidate();
	UpdateWindow();
}


void TBitmapWin::CmHideBitmap()
{
	showBitmap = FALSE;
	Invalidate();
	UpdateWindow();
}


void TBitmapWin::CmEnableShowBitmap(TCommandEnabler &ce)
{
	ce.Enable(!showBitmap);
}

void TBitmapWin::CmEnableHideBitmap(TCommandEnabler &ce)
{
	ce.Enable(showBitmap);
}

///////////////////////////////////////////////////////////////////////////
class TClientWndw: public TMDIClient
{
public:
	TClientWndw();
protected:
	void CmFileNew();
	void CmDisplayBmp();
	void CmEnableDisplayBmp(TCommandEnabler &ce);
private:
	int childNum;
	TWindow *bitmapWin;
DECLARE_RESPONSE_TABLE(TClientWndw);
};

DEFINE_RESPONSE_TABLE1(TClientWndw, TMDIClient)
	EV_COMMAND(CM_FILENEW, CmFileNew),
	EV_COMMAND(CM_DISPLAYBMP, CmDisplayBmp),
	EV_COMMAND_ENABLE(CM_DISPLAYBMP, CmEnableDisplayBmp),
END_RESPONSE_TABLE;


TClientWndw::TClientWndw()
	: TMDIClient(),
		childNum(1)
{
//	bitmapWin = new TBitmapWin(this, "Bitmap");
	bitmapWin = new TBitmapWin(*this, "Bitmap");
	bitmapWin->DisableAutoCreate();
}


void TClientWndw::CmFileNew()
{
	char title[20];
	wsprintf(title, "Child Window #%d", childNum++);
	TWindow *wndw = new TChildWndw1(*this, title);
	wndw->Create();
}


void TClientWndw::CmDisplayBmp()
{
	if (bitmapWin->HWindow)
		bitmapWin->Destroy();
	else
		bitmapWin->Create();
}


void TClientWndw::CmEnableDisplayBmp(TCommandEnabler &ce)
{
	ce.SetCheck(bitmapWin->HWindow ?
		TCommandEnabler::Checked : TCommandEnabler::Unchecked);
}

///////////////////////////////////////////////////////////////////////////
class TApp: public TApplication
{
public:
	TApp(): TApplication() {};
	void InitMainWindow();
};


void TApp::InitMainWindow()
{
	TMDIClient *client = new TClientWndw();
	TMDIFrame *wndw = new TMDIFrame("MDI Dynamic Menu", MENU_1, *client);

	wndw->Attr.X = GetSystemMetrics(SM_CXSCREEN) / 8;
	wndw->Attr.Y = GetSystemMetrics(SM_CYSCREEN) / 8;
	wndw->Attr.H = wndw->Attr.Y * 6;
	wndw->Attr.W = wndw->Attr.X * 6;

	TMenuDescr menuDescr(MENU_1, 1, 0, 1, 0, 0, 1);
	wndw->SetMenuDescr(menuDescr);
	SetMainWindow(wndw);
}


int OwlMain(int, char*[])
{
	return TApp().Run();
}

